# Security Policy

## Reporting a Vulnerability

Please report security vulnerabilities to security@khanoit.co.za

## Supported Versions

| Version | Supported          |
| ------- | ------------------ |
| 0.1.8   | :white_check_mark: |
| 0.1.7   | :white_check_mark: |
| 0.1.6   | :white_check_mark: |
| < 1.3   | :x:                |
